# CLAUDE.md

<!-- Claude Code requires this filename for project instructions.
     All agent-facing guidance lives in AGENTS.md (the single source of truth
     for any AI coding agent). See HARNESS.md for the rationale. -->

Read and follow [AGENTS.md](../AGENTS.md) for all project instructions.
